@@ -10,7 +10,6 @@ NULL
 #' Missing values are replaced in atomic vectors; `NULL`s are replaced
 #' in list.
 #'
-#' @inheritParams expand
 #' @inheritParams gather
 #' @param .direction Direction in which to fill missing values. Currently
 #'   either "down" (the default) or "up".
@@ -22,10 +21,6 @@ fill <- function(data, ..., .direction = c("down", "up")) {
   UseMethod("fill")
 }
 #' @export
-fill.default <- function(data, ..., .direction = c("down", "up")) {
-  fill_(data, fill_cols = compat_as_lazy_dots(...), .direction = .direction)
-}
-#' @export
 fill.data.frame <- function(data, ..., .direction = c("down", "up")) {
   fill_cols <- unname(tidyselect::vars_select(names(data), ...))
 
@@ -42,17 +37,3 @@ fill.data.frame <- function(data, ..., .direction = c("down", "up")) {
 fill.grouped_df <- function(data, ..., .direction = c("down", "up")) {
   dplyr::do(data, fill(., ..., .direction = .direction))
 }
-
-
-#' @rdname deprecated-se
-#' @inheritParams fill
-#' @param fill_cols Character vector of column names.
-#' @export
-fill_ <- function(data, fill_cols, .direction = c("down", "up")) {
-  UseMethod("fill_")
-}
-#' @export
-fill_.data.frame <- function(data, fill_cols, .direction = c("down", "up")) {
-  vars <- syms(fill_cols)
-  fill(data, !!! vars, .direction = .direction)
-}
